@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2-Wnck/wnck2perl.h,v 1.2 2003/10/12 01:27:28 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2-Wnck/wnck2perl.h,v 1.6 2005/09/17 20:30:37 kaffeetisch Exp $
  */
 
 #ifndef _WNCK2PERL_H_
@@ -25,9 +25,17 @@
 
 #include <libwnck/libwnck.h>
 #include <libwnck/window-action-menu.h>
-#include <libwnck/window-menu.h>
 
-#include "wnck2perl-autogen.h"
 #include "wnck2perl-version.h"
 
+#if !WNCK_CHECK_VERSION (2, 10, 0)
+# include <libwnck/window-menu.h>
+#endif
+
+#if WNCK_CHECK_VERSION (2, 6, 0)
+# include <libwnck/class-group.h>
+#endif
+
+#include "wnck2perl-autogen.h"
+
 #endif /* _WNCK2PERL_H_ */
